@@ -6,9 +6,10 @@
 
 #include "kcm.h"
 
+#include "configuration.h"
 #include "connectioneditordialog.h"
-#include "debug.h"
 #include "mobileconnectionwizard.h"
+#include "plasma_nm_kcm.h"
 #include "settings/wireguardinterfacewidget.h"
 #include "uiutils.h"
 #include "vpnuiplugin.h"
@@ -42,25 +43,23 @@
 #include <QQuickItem>
 #include <QQuickView>
 #include <QQuickWidget>
+#include <QStringBuilder>
 #include <QTimer>
 #include <QVBoxLayout>
 
-K_PLUGIN_FACTORY(KCMNetworkConfigurationFactory, registerPlugin<KCMNetworkmanagement>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMNetworkmanagement, "kcm_networkmanagement.json")
 
 KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
     , m_handler(new Handler(this))
-    , m_tabWidget(nullptr)
     , m_ui(new Ui::KCMForm)
 {
-    QWidget *mainWidget = new QWidget(this);
+    auto mainWidget = new QWidget(this);
     m_ui->setupUi(mainWidget);
 
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(m_ui->connectionView->engine());
-    kdeclarative.setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     kdeclarative.setupEngine(m_ui->connectionView->engine());
-    kdeclarative.setupContext();
 
     // Check if we can use AP mode to identify security type
     bool useApMode = false;
@@ -112,7 +111,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
     connect(rootItem, SIGNAL(requestExportConnection(QString)), this, SLOT(onRequestExportConnection(QString)));
     connect(rootItem, SIGNAL(requestToChangeConnection(QString, QString)), this, SLOT(onRequestToChangeConnection(QString, QString)));
 
-    QVBoxLayout *l = new QVBoxLayout(this);
+    auto l = new QVBoxLayout(this);
     l->addWidget(mainWidget);
 
     setButtons(Button::Apply);
@@ -127,7 +126,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
             if (uuid.startsWith(uuidArgumentMarker)) {
                 uuid = uuid.replace(uuidArgumentMarker, QString());
                 selectedConnection = NetworkManager::findConnectionByUuid(uuid);
-                qDebug() << "Selecting user connection:" << uuid;
+                qDebug(PLASMA_NM_KCM_LOG) << "Selecting user connection:" << uuid;
                 break;
             }
         }
@@ -138,7 +137,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
         NetworkManager::ActiveConnection::Ptr activeConnection = NetworkManager::primaryConnection();
         if (activeConnection && activeConnection->isValid()) {
             selectedConnection = activeConnection->connection();
-            qDebug() << "Selecting active connection:" << selectedConnection->uuid();
+            qDebug(PLASMA_NM_KCM_LOG) << "Selecting active connection:" << selectedConnection->uuid();
         }
     }
 
@@ -177,7 +176,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
             const NetworkManager::ConnectionSettings::ConnectionType type = connection->settings()->connectionType();
             if (UiUtils::isConnectionTypeSupported(type)) {
                 selectedConnection = connection;
-                qDebug() << "Selecting first connection:" << connection->uuid();
+                qDebug(PLASMA_NM_KCM_LOG) << "Selecting first connection:" << connection->uuid();
                 break;
             }
         }
@@ -189,7 +188,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
             QMetaObject::invokeMethod(rootItem, "selectConnection", Q_ARG(QVariant, settings->id()), Q_ARG(QVariant, selectedConnection->path()));
         }
     } else {
-        qDebug() << "Cannot preselect a connection";
+        qDebug(PLASMA_NM_KCM_LOG) << "Cannot preselect a connection";
     }
 
     connect(NetworkManager::settingsNotifier(),
@@ -212,9 +211,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
 KCMNetworkmanagement::~KCMNetworkmanagement()
 {
     delete m_handler;
-    if (m_tabWidget) {
-        delete m_tabWidget;
-    }
+    delete m_tabWidget;
     delete m_ui;
 }
 
@@ -275,7 +272,7 @@ void KCMNetworkmanagement::onConnectionAdded(const QString &connection)
 
 void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const QString &vpnType, const QString &specificType, bool shared)
 {
-    NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(connectionType);
+    auto type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(connectionType);
 
     if (type == NetworkManager::ConnectionSettings::Vpn && vpnType == "imported") {
         importVpn();
@@ -284,10 +281,10 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
         QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
         connect(wizard.data(), &MobileConnectionWizard::accepted, [wizard, this]() {
             if (wizard->getError() == MobileProviders::Success) {
-                qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << wizard->type() << wizard->args();
+                qCDebug(PLASMA_NM_KCM_LOG) << "Mobile broadband wizard finished:" << wizard->type() << wizard->args();
 
                 if (wizard->args().count() == 2) {
-                    QVariantMap tmp = qdbus_cast<QVariantMap>(wizard->args().value(1));
+                    auto tmp = qdbus_cast<QVariantMap>(wizard->args().value(1));
 
                     NetworkManager::ConnectionSettings::Ptr connectionSettings;
                     connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(wizard->type()));
@@ -301,13 +298,13 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
                     } else if (wizard->type() == NetworkManager::ConnectionSettings::Cdma) {
                         connectionSettings->setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
                     } else {
-                        qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unhandled setting type";
+                        qCWarning(PLASMA_NM_KCM_LOG) << Q_FUNC_INFO << "Unhandled setting type";
                     }
                     // Generate new UUID
                     connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
                     addConnection(connectionSettings);
                 } else {
-                    qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unexpected number of args to parse";
+                    qCWarning(PLASMA_NM_KCM_LOG) << Q_FUNC_INFO << "Unexpected number of args to parse";
                 }
             }
         });
@@ -385,6 +382,12 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
         connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
         addConnection(connectionSettings);
     }
+
+    // Automatically enable virtual connection management if one is created
+    if (type == NetworkManager::ConnectionSettings::Vlan || type == NetworkManager::ConnectionSettings::Bridge
+        || type == NetworkManager::ConnectionSettings::Bond || type == NetworkManager::ConnectionSettings::Team) {
+        Configuration::self().setManageVirtualConnections(true);
+    }
 }
 
 void KCMNetworkmanagement::onRequestExportConnection(const QString &connectionPath)
@@ -401,14 +404,14 @@ void KCMNetworkmanagement::onRequestExportConnection(const QString &connectionPa
 
     NetworkManager::VpnSetting::Ptr vpnSetting = connSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
 
-    qCDebug(PLASMA_NM) << "Exporting VPN connection" << connection->name() << "type:" << vpnSetting->serviceType();
+    qCDebug(PLASMA_NM_KCM_LOG) << "Exporting VPN connection" << connection->name() << "type:" << vpnSetting->serviceType();
 
     const auto result = VpnUiPlugin::loadPluginForType(nullptr, vpnSetting->serviceType());
 
     if (result) {
         std::unique_ptr<VpnUiPlugin> vpnPlugin(result.plugin);
         if (vpnPlugin->suggestedFileName(connSettings).isEmpty()) { // this VPN doesn't support export
-            qCWarning(PLASMA_NM) << "This VPN doesn't support export";
+            qCWarning(PLASMA_NM_KCM_LOG) << "This VPN doesn't support export";
             return;
         }
 
@@ -418,13 +421,13 @@ void KCMNetworkmanagement::onRequestExportConnection(const QString &connectionPa
         if (!filename.isEmpty()) {
             if (!vpnPlugin->exportConnectionSettings(connSettings, filename)) {
                 // TODO display failure
-                qCWarning(PLASMA_NM) << "Failed to export VPN connection";
+                qCWarning(PLASMA_NM_KCM_LOG) << "Failed to export VPN connection";
             } else {
                 // TODO display success
             }
         }
     } else {
-        qCWarning(PLASMA_NM) << "Error getting VpnUiPlugin for export:" << result.errorText;
+        qCWarning(PLASMA_NM_KCM_LOG) << "Error getting VpnUiPlugin for export:" << result.errorText;
     }
 }
 
@@ -504,8 +507,7 @@ void KCMNetworkmanagement::loadConnectionSettings(const NetworkManager::Connecti
                 kcmChanged(valid);
             }
         });
-        QVBoxLayout *layout = new QVBoxLayout(m_ui->connectionConfiguration);
-        layout->addWidget(m_tabWidget);
+        m_ui->horizontalLayout->addWidget(m_tabWidget);
     }
 
     kcmChanged(false);
@@ -531,7 +533,7 @@ void KCMNetworkmanagement::importVpn()
 
         QFileInfo fi(filename);
         const QString ext = QStringLiteral("*.") % fi.suffix();
-        qCDebug(PLASMA_NM) << "Importing VPN connection " << filename << "extension:" << ext;
+        qCDebug(PLASMA_NM_KCM_LOG) << "Importing VPN connection " << filename << "extension:" << ext;
 
         // Handle WireGuard separately because it is different than all the other VPNs
         if (WireGuardInterfaceWidget::supportedFileExtensions().contains(ext)) {
@@ -540,10 +542,10 @@ void KCMNetworkmanagement::importVpn()
             connectionSettings.fromMap(connection);
             connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
-            // qCDebug(PLASMA_NM) << "Converted connection:" << connectionSettings;
+            // qCDebug(PLASMA_NM_KCM_LOG) << "Converted connection:" << connectionSettings;
 
             m_handler->addConnection(connectionSettings.toMap());
-            // qCDebug(PLASMA_NM) << "Adding imported connection under id:" << conId;
+            // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
 
             if (!connection.isEmpty()) {
                 return; // get out if the import produced at least some output
@@ -559,20 +561,20 @@ void KCMNetworkmanagement::importVpn()
             std::unique_ptr<VpnUiPlugin> vpnPlugin(result.plugin);
 
             if (vpnPlugin->supportedFileExtensions().contains(ext)) {
-                qCDebug(PLASMA_NM) << "Found VPN plugin" << service.name() << ", type:" << service.value("X-NetworkManager-Services");
+                qCDebug(PLASMA_NM_KCM_LOG) << "Found VPN plugin" << service.name() << ", type:" << service.value("X-NetworkManager-Services");
 
                 NMVariantMapMap connection = vpnPlugin->importConnectionSettings(filename);
 
-                // qCDebug(PLASMA_NM) << "Raw connection:" << connection;
+                // qCDebug(PLASMA_NM_KCM_LOG) << "Raw connection:" << connection;
 
                 NetworkManager::ConnectionSettings connectionSettings;
                 connectionSettings.fromMap(connection);
                 connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
 
-                // qCDebug(PLASMA_NM) << "Converted connection:" << connectionSettings;
+                // qCDebug(PLASMA_NM_KCM_LOG) << "Converted connection:" << connectionSettings;
 
                 m_handler->addConnection(connectionSettings.toMap());
-                // qCDebug(PLASMA_NM) << "Adding imported connection under id:" << conId;
+                // qCDebug(PLASMA_NM_KCM_LOG) << "Adding imported connection under id:" << conId;
 
                 if (connection.isEmpty()) { // the "positive" part will arrive with connectionAdded
                     // TODO display success
@@ -591,7 +593,6 @@ void KCMNetworkmanagement::resetSelection()
     QObject *rootItem = m_ui->connectionView->rootObject();
     QMetaObject::invokeMethod(rootItem, "deselectConnections");
     if (m_tabWidget) {
-        delete m_ui->connectionConfiguration->layout();
         delete m_tabWidget;
         m_tabWidget = nullptr;
     }
