@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "wireguardinterfacewidget.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "simpleiplistvalidator.h"
 #include "simpleipv4addressvalidator.h"
 #include "uiutils.h"
@@ -365,18 +365,13 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
     }
 
     const QString connectionName = QFileInfo(fileName).completeBaseName();
-    NMStringMap dataMap;
     NMVariantMapList peers;
-    QVariantMap ipv4Data;
     QVariantMap *currentPeer = nullptr;
     WireGuardKeyValidator keyValidator;
     NetworkManager::Ipv4Setting ipv4Setting;
     NetworkManager::Ipv6Setting ipv6Setting;
     NetworkManager::WireGuardSetting wgSetting;
 
-    QString proxyType;
-    QString proxyUser;
-    QString proxyPasswd;
     bool havePrivateKey = false;
     bool haveIpv4Setting = false;
     bool haveIpv6Setting = false;
@@ -398,7 +393,7 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
         QString line = in.readLine();
 
         // Remove comments starting with '#'
-        if (int index = line.indexOf('#') > 0)
+        if (int index = line.indexOf(QLatin1Char('#')) > 0)
             line.truncate(index);
 
         // Ignore blank lines
@@ -406,7 +401,7 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
             continue;
 
         keyValue.clear();
-        keyValue << line.split('=');
+        keyValue << line.split(QLatin1Char('='));
 
         if (keyValue[0] == PNM_WG_CONF_TAG_INTERFACE) {
             currentState = INTERFACE_SECTION;
@@ -438,13 +433,13 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
         if (currentState == INTERFACE_SECTION) {
             // Address
             if (key == PNM_WG_CONF_TAG_ADDRESS) {
-                QStringList valueList = keyValue[1].split(',');
+                QStringList valueList = keyValue[1].split(QLatin1Char(','));
                 if (valueList.isEmpty())
                     return result;
 
                 for (const QString &address : valueList) {
                     const QPair<QHostAddress, int> addressIn = QHostAddress::parseSubnet(address.trimmed());
-                    NetworkManager::IpAddress *addr = new NetworkManager::IpAddress;
+                    auto addr = new NetworkManager::IpAddress;
                     addr->setIp(addressIn.first);
                     addr->setPrefixLength(addressIn.second);
                     if (addressIn.first.protocol() == QAbstractSocket::NetworkLayerProtocol::IPv4Protocol) {
@@ -485,7 +480,7 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
                     havePrivateKey = true;
                 }
             } else if (key == PNM_WG_CONF_TAG_DNS) {
-                QStringList addressList = keyValue[1].split(',');
+                QStringList addressList = keyValue[1].split(QLatin1Char(','));
                 QList<QHostAddress> ipv4DnsList;
                 QList<QHostAddress> ipv6DnsList;
                 if (!addressList.isEmpty()) {
@@ -558,7 +553,7 @@ NMVariantMapMap WireGuardInterfaceWidget::importConnectionSettings(const QString
                 SimpleIpListValidator validator(SimpleIpListValidator::WithCidr, SimpleIpListValidator::Both);
                 QString val = keyValue[1].trimmed();
                 if (QValidator::Acceptable == validator.validate(val, pos)) {
-                    QStringList valList = val.split(',');
+                    QStringList valList = val.split(QLatin1Char(','));
                     for (QString &str : valList)
                         str = str.trimmed();
                     currentPeer->insert(PNM_WG_PEER_KEY_ALLOWED_IPS, valList);
