@@ -93,8 +93,6 @@ void Handler::activateConnection(const QString &connection, const QString &devic
         if (vpnSetting) {
             qCDebug(PLASMA_NM_LIBS_LOG) << "Checking VPN" << con->name() << "type:" << vpnSetting->serviceType();
 
-            bool pluginMissing = false;
-
             // Check missing plasma-nm VPN plugin
 
             const auto filter = [vpnSetting](const KPluginMetaData &md) -> bool {
@@ -103,7 +101,13 @@ void Handler::activateConnection(const QString &connection, const QString &devic
 
             const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"), filter);
 
-            pluginMissing = plugins.isEmpty();
+            const QString pluginBaseName = vpnSetting->serviceType().remove(QLatin1String("org.freedesktop.NetworkManager."));
+            bool pluginMissing = plugins.isEmpty();
+            QString errorMessage;
+
+            if (plugins.empty()) {
+                errorMessage = i18n("Plasma is missing support for '%1' VPN connections. Please report this to your distribution.", pluginBaseName);
+            }
 
             // Check missing NetworkManager VPN plugin
             if (!pluginMissing) {
@@ -112,15 +116,16 @@ void Handler::activateConnection(const QString &connection, const QString &devic
 
                 NMVpnPluginInfo *plugin_info = nm_vpn_plugin_info_list_find_by_service(plugins, vpnSetting->serviceType().toStdString().c_str());
                 pluginMissing = !plugin_info;
+                errorMessage = i18n("NetworkManager is missing support for '%1' VPN connections. Please use the package manager to install it.", pluginBaseName);
             }
 
             if (pluginMissing) {
                 qCWarning(PLASMA_NM_LIBS_LOG) << "VPN" << vpnSetting->serviceType() << "not found, skipping";
-                auto notification = new KNotification(QStringLiteral("MissingVpnPlugin"), KNotification::CloseOnTimeout, this);
+                auto notification = new KNotification(QStringLiteral("MissingVpnPlugin"), KNotification::Persistent, this);
                 notification->setComponentName(QStringLiteral("networkmanagement"));
                 notification->setTitle(con->name());
-                notification->setText(i18n("Missing VPN plugin"));
-                notification->setIconName(QStringLiteral("dialog-warning"));
+                notification->setText(errorMessage);
+                notification->setIconName(QStringLiteral("dialog-error"));
                 notification->sendEvent();
                 return;
             }
@@ -752,7 +757,7 @@ void Handler::secretAgentError(const QString &connectionPath, const QString &mes
 {
     // If the password was wrong, forget it
     removeConnection(connectionPath);
-    emit connectionActivationFailed(connectionPath, message);
+    Q_EMIT connectionActivationFailed(connectionPath, message);
 }
 
 void Handler::replyFinished(QDBusPendingCallWatcher *watcher)
